@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/ed.init.c,v 3.42 2000/01/14 22:57:26 christos Exp $ */
+/* $Header: /src/pub/tcsh/ed.init.c,v 3.44 2001/02/19 23:30:44 kim Exp $ */
 /*
  * ed.init.c: Editor initializations
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: ed.init.c,v 3.42 2000/01/14 22:57:26 christos Exp $")
+RCSID("$Id: ed.init.c,v 3.44 2001/02/19 23:30:44 kim Exp $")
 
 #include "ed.h"
 #include "ed.term.h"
@@ -177,7 +177,7 @@ ed_Setup(rst)
 	return(0);
 
 #if defined(POSIX) && defined(_PC_VDISABLE) && !defined(BSD4_4) && \
-    !defined(WINNT)
+    !defined(WINNT_NATIVE)
     { 
 	long pcret;
 
@@ -193,9 +193,9 @@ ed_Setup(rst)
 		    ttychars[EX_IO][rst] = vdisable;
 	    }
     }
-#else /* ! POSIX || !_PC_VDISABLE || BSD4_4 || WINNT */
+#else /* ! POSIX || !_PC_VDISABLE || BSD4_4 || WINNT_NATIVE */
     vdisable = (unsigned char) _POSIX_VDISABLE;
-#endif /* POSIX && _PC_VDISABLE && !BSD4_4 && !WINNT */
+#endif /* POSIX && _PC_VDISABLE && !BSD4_4 && !WINNT_NATIVE */
 	
     if ((imode = adrof(STRinputmode)) != NULL) {
 	if (!Strcmp(*(imode->vec), STRinsert))
@@ -208,8 +208,9 @@ ed_Setup(rst)
     ed_InitMaps();
     Hist_num = 0;
     Expand = 0;
+    SetKillRing(getn(varval(STRkillring)));
 
-#ifndef WINNT
+#ifndef WINNT_NATIVE
     if (tty_getty(SHTTY, &extty) == -1) {
 # ifdef DEBUG_TTY
 	xprintf("ed_Setup: tty_getty: %s\n", strerror(errno));
@@ -288,12 +289,12 @@ ed_Setup(rst)
 # ifdef SIG_WINDOW
     (void) sigset(SIG_WINDOW, window_change);	/* for window systems */
 # endif 
-#else /* WINNT */
+#else /* WINNT_NATIVE */
 # ifdef DEBUG
     if (rst)
 	xprintf("rst received in ed_Setup() %d\n", rst);
 # endif
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
     havesetup = 1;
     return(0);
 }
@@ -303,7 +304,27 @@ ed_Init()
 {
     ResetInLine(1);		/* reset the input pointers */
     GettingInput = 0;		/* just in case */
-    LastKill = KillBuf;		/* no kill buffer */
+#ifdef notdef
+    /* XXX This code was here before the kill ring:
+    LastKill = KillBuf;		/ * no kill buffer * /
+       If there was any reason for that other than to make sure LastKill
+       was initialized, the code below should go in here instead - but
+       it doesn't seem reasonable to lose the entire kill ring (which is
+       "self-initializing") just because you set $term or whatever, so
+       presumably this whole '#ifdef notdef' should just be taken out.  */
+
+    {				/* no kill ring - why? */
+	int i;
+	for (i = 0; i < KillRingMax; i++) {
+	    if (KillRing[i].buf != NULL)
+		xfree((ptr_t) KillRing[i].buf);
+	    KillRing[i].buf = NULL;
+	    KillRing[i].len = 0;
+	}
+	YankPos = KillPos = 0;
+	KillRingLen = 0;
+    }
+#endif
 
 #ifdef DEBUG_EDIT
     CheckMaps();		/* do a little error checking on key maps */
@@ -321,7 +342,7 @@ ed_Init()
 	GetTermCaps();		/* does the obvious, but gets term type each
 				 * time */
 
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 # if defined(TERMIO) || defined(POSIX)
     edtty.d_t.c_iflag &= ~ttylist[ED_IO][M_INPUT].t_clrmask;
     edtty.d_t.c_iflag |=  ttylist[ED_IO][M_INPUT].t_setmask;
@@ -356,7 +377,7 @@ ed_Init()
 # endif /* POSIX || TERMIO */
 
     tty_setchar(&edtty, ttychars[ED_IO]);
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 }
 
 /* 
@@ -368,9 +389,9 @@ Rawmode()
     if (Tty_raw_mode)
 	return (0);
 
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     do_nt_raw_mode();
-#else /* !WINNT */
+#else /* !WINNT_NATIVE */
 # ifdef _IBMR2
     tty_setdisc(SHTTY, ED_IO);
 # endif /* _IBMR2 */
@@ -542,7 +563,7 @@ Rawmode()
 # endif /* DEBUG_TTY */
 	return(-1);
     }
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
     Tty_raw_mode = 1;
     flush();			/* flush any buffered output */
     return (0);
@@ -551,7 +572,7 @@ Rawmode()
 int
 Cookedmode()
 {				/* set tty in normal setup */
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     do_nt_cooked_mode();
 #else
     signalfun_t orig_intr;
@@ -603,7 +624,7 @@ Cookedmode()
 # else
     (void) sigset(SIGINT, orig_intr);	/* take these again */
 # endif /* BSDSIGS */
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
     Tty_raw_mode = 0;
     return (0);
@@ -623,9 +644,6 @@ ResetInLine(macro)
     Hist_num = 0;
     DoingArg = 0;
     Argument = 1;
-#ifdef notdef
-    LastKill = KillBuf;		/* no kill buffer */
-#endif 
     LastCmd = F_UNASSIGNED;	/* previous command executed */
     if (macro)
 	MacroLvl = -1;		/* no currently active macros */
@@ -688,7 +706,7 @@ QuoteModeOn()
     if (MacroLvl >= 0)
 	return;
 
-#ifndef WINNT
+#ifndef WINNT_NATIVE
     qutty = edtty;
 
 #if defined(TERMIO) || defined(POSIX)
@@ -716,7 +734,7 @@ QuoteModeOn()
 #endif /* DEBUG_TTY */
 	return;
     }
-#endif /* !WINNT */
+#endif /* !WINNT_NATIVE */
     Tty_quote_mode = 1;
     return;
 }
