@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/ed.term.c,v 1.24 1999/08/12 14:19:23 christos Exp $ */
+/* $Header: /src/pub/tcsh/ed.term.c,v 1.26 2001/08/06 23:51:09 christos Exp $ */
 /*
  * ed.term.c: Low level terminal interface
  */
@@ -35,9 +35,9 @@
  * SUCH DAMAGE.
  */
 #include "sh.h"
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 
-RCSID("$Id: ed.term.c,v 1.24 1999/08/12 14:19:23 christos Exp $")
+RCSID("$Id: ed.term.c,v 1.26 2001/08/06 23:51:09 christos Exp $")
 
 #include "ed.h"
 #include "ed.term.h"
@@ -566,14 +566,21 @@ static struct tcshmodes {
 # define OKERROR(e) ((e) == EINTR)
 #endif
 
+#ifdef __NetBSD__
+#define KLUDGE (errno == ENOTTY && count < 10)
+#else
+#define KLUDGE 0
+#endif
+
 /* Retry a system call */
+static int count;
 #define RETRY(x) \
-   for (;;) \
+   for (count = 0;; count++) \
 	if ((x) == -1) { \
-	   if (OKERROR(errno)) \
-	       continue; \
-	   else \
-	       return -1; \
+	    if (OKERROR(errno) || KLUDGE) \
+		continue; \
+	    else \
+		return -1; \
 	} \
 	else \
 	   break \
@@ -1140,11 +1147,11 @@ tty_printchar(s)
     xputchar('\n');
 }
 #endif /* DEBUG_TTY */
-#else /* WINNT */
+#else /* WINNT_NATIVE */
 int
 tty_cooked_mode(td)
     void *td;
 {
     return do_nt_check_cooked_mode();
 }
-#endif /* !WINNT */
+#endif /* !WINNT_NATIVE */
