@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.c,v 3.91 2000/07/04 19:42:47 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.c,v 3.95 2001/04/27 22:36:39 christos Exp $ */
 /*
  * sh.c: Main shell routines
  */
@@ -43,7 +43,7 @@ char    copyright[] =
  All rights reserved.\n";
 #endif /* not lint */
 
-RCSID("$Id: sh.c,v 3.91 2000/07/04 19:42:47 christos Exp $")
+RCSID("$Id: sh.c,v 3.95 2001/04/27 22:36:39 christos Exp $")
 
 #include "tc.h"
 #include "ed.h"
@@ -86,9 +86,9 @@ extern bool NoNLSRebind;
 jmp_buf_t reslab INIT_ZERO_STRUCT;
 
 static const char tcshstr[] = "tcsh";
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 static const char tcshstr_nt[] = "tcsh.exe";
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
 signalfun_t parintr = 0;	/* Parents interrupt catch */
 signalfun_t parterm = 0;	/* Parents terminate catch */
@@ -124,6 +124,7 @@ time_t  t_period;
 Char  *ffile = NULL;
 bool	dolzero = 0;
 int	insource = 0;
+int	exitset = 0;
 static time_t  chktim;		/* Time mail last checked */
 char *progname;
 int tcsh;
@@ -159,7 +160,11 @@ struct saved_state {
 };
 
 static	int		  srccat	__P((Char *, Char *));
+#ifndef WINNT_NATIVE
 static	int		  srcfile	__P((char *, bool, int, Char **));
+#else
+int		  srcfile	__P((char *, bool, int, Char **));
+#endif /*WINNT_NATIVE*/
 static	sigret_t	  phup		__P((int));
 static	void		  srcunit	__P((int, bool, int, Char **));
 static	void		  mailchk	__P((void));
@@ -190,9 +195,9 @@ main(argc, argv)
     sigvec_t osv;
 #endif /* BSDSIGS */
 
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     nt_init();
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 #if defined(NLS_CATALOGS) && defined(LC_MESSAGES)
     (void) setlocale(LC_MESSAGES, "");
 #endif /* NLS_CATALOGS && LC_MESSAGES */
@@ -248,13 +253,13 @@ main(argc, argv)
 	char *t;
 
 	t = strrchr(argv[0], '/');
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 	{
 	    char *s = strrchr(argv[0], '\\');
 	    if (s)
 		t = s;
 	}
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 	t = t ? t + 1 : argv[0];
 	if (*t == '-') t++;
 	progname = strsave((t && *t) ? t : tcshstr);    /* never want a null */
@@ -527,14 +532,26 @@ main(argc, argv)
      */
     shlvl(1);
 
-    if ((tcp = getenv("HOME")) != NULL)
-	cp = quote(SAVE(tcp));
-    else
+    if ((tcp = getenv("HOME")) != NULL) {
+	if (strlen(tcp) >= MAXPATHLEN) {
+	    struct passwd *pw;
+	    if ((pw = getpwuid(getuid())) != NULL)
+		cp = quote(SAVE(pw->pw_dir));
+	    else {
+		tcp[MAXPATHLEN-1] = '\0';
+		cp = quote(SAVE(tcp));
+	    }
+	} else {
+	    cp = quote(SAVE(tcp));
+	}
+    } else
 	cp = NULL;
+
     if (cp == NULL)
 	fast = 1;		/* No home -> can't read scripts */
     else
 	set(STRhome, cp, VAR_READWRITE);
+
     dinit(cp);			/* dinit thinks that HOME == cwd in a login
 				 * shell */
     /*
@@ -662,6 +679,11 @@ main(argc, argv)
      */
     set(STRaddsuffix, Strsave(STRNULL), VAR_READWRITE);
 
+    /*
+     * Random default kill ring size
+     */
+    set(STRkillring, SAVE("30"), VAR_READWRITE);
+
     /*
      * Re-initialize path if set in environment
      */
@@ -708,16 +730,16 @@ main(argc, argv)
 #endif /* COLOR_LS_F */
 
     doldol = putn((int) getpid());	/* For $$ */
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     {
 	char *strtmp1, strtmp2[MAXPATHLEN];
 	if ((strtmp1 = getenv("TMP")) != NULL)
 	    wsprintf(strtmp2, "%s/%s", strtmp1, "sh");
 	shtemp = Strspl(SAVE(strtmp2), doldol);	/* For << */
     }
-#else /* !WINNT */
+#else /* !WINNT_NATIVE */
     shtemp = Strspl(STRtmpsh, doldol);	/* For << */
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
     /*
      * Record the interrupt states from the parent process. If the parent is
@@ -759,6 +781,24 @@ main(argc, argv)
     (void) signal(SIGMIGRATE, SIG_DFL);
 #endif /* TCF */
 
+    /*
+     * dspkanji/dspmbyte autosetting
+     */
+    /* PATCH IDEA FROM Issei.Suzuki VERY THANKS */
+#if defined(DSPMBYTE)
+#if defined(NLS) && defined(LC_CTYPE)
+    if (((tcp = setlocale(LC_CTYPE, NULL)) != NULL || (tcp = getenv("LANG")) != NULL) && !adrof(CHECK_MBYTEVAR)) {
+#else
+    if ((tcp = getenv("LANG")) != NULL && !adrof(CHECK_MBYTEVAR)) {
+#endif
+	autoset_dspmbyte(str2short(tcp));
+    }
+#if defined(WINNT_NATIVE)
+    else if (!adrof(CHECK_MBYTEVAR))
+      nt_autoset_dspmbyte();
+#endif /* WINNT_NATIVE */
+#endif
+
     /*
      * Process the arguments.
      * 
@@ -1211,6 +1251,7 @@ main(argc, argv)
      * start-up scripts.
      */
     reenter = setexit();	/* PWP */
+    exitset++;
     haderr = 0;			/* In case second time through */
     if (!fast && reenter == 0) {
 	/* Will have varval(STRhome) here because set fast if don't */
@@ -1281,20 +1322,6 @@ main(argc, argv)
 #endif				/* SIG_WINDOW */
     }
 
-    /*
-     * dspkanji/dspmbyte autosetting
-     */
-    /* PATCH IDEA FROM Issei.Suzuki VERY THANKS */
-#if defined(DSPMBYTE)
-    if ((tcp = getenv("LANG")) != NULL && !adrof(CHECK_MBYTEVAR)) {
-	autoset_dspmbyte(str2short(tcp));
-    }
-#if defined(WINNT)
-    else if (!adrof(CHECK_MBYTEVAR))
-      nt_autoset_dspmbyte();
-#endif /* WINNT */
-#endif
-
     /*
      * Now are ready for the -v and -x flags
      */
@@ -1376,10 +1403,10 @@ importpath(cp)
 		else
 		    break;
 	    }
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 	    else if (*dp == '\\')
 		*dp = '/';
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 	    dp++;
 	}
     pv[i] = 0;
@@ -1400,13 +1427,13 @@ srccat(cp, dp)
 	char   *ptr;
 	int rv;
 
-#ifdef WINNT
+#ifdef WINNT_NATIVE
 	ep = cp;
 	while(*ep)
 	    ep++;
 	if (ep[-1] == '/' && dp[0] == '/') /* silly win95 */
 	    dp++;
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
 
 	ep = Strspl(cp, dp);
 	ptr = short2str(ep);
@@ -1420,7 +1447,11 @@ srccat(cp, dp)
 /*
  * Source to a file putting the file descriptor in a safe place (> 2).
  */
+#ifndef WINNT_NATIVE
 static int
+#else
+int
+#endif /*WINNT_NATIVE*/
 srcfile(f, onlyown, flag, av)
     char   *f;
     bool    onlyown;
@@ -1850,9 +1881,9 @@ pintr1(wantnl)
     (void) sigrelse(SIGCHLD);
 #endif
     drainoline();
-#if !defined(_VMS_POSIX) && !defined(WINNT)
+#if !defined(_VMS_POSIX) && !defined(WINNT_NATIVE)
     (void) endpwent();
-#endif /* !_VMS_POSIX && !WINNT */
+#endif /* !_VMS_POSIX && !WINNT_NATIVE */
 
     /*
      * If we have an active "onintr" then we search for the label. Note that if
@@ -2373,9 +2404,9 @@ xexit(i)
     if (child == 0)
 	(void) catclose(catd);
 #endif /* NLS_CATALOGS */
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     nt_cleanup();
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
     _exit(i);
 }
 
