@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.dir.c,v 3.53 2000/07/04 19:39:22 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.dir.c,v 3.56 2001/01/29 01:28:02 christos Exp $ */
 /*
  * sh.dir.c: Directory manipulation functions
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.dir.c,v 3.53 2000/07/04 19:39:22 christos Exp $")
+RCSID("$Id: sh.dir.c,v 3.56 2001/01/29 01:28:02 christos Exp $")
 
 /*
  * C Shell - directory management
@@ -513,11 +513,11 @@ dgoto(cp)
     else
 	dp = cp;
 
-#ifdef WINNT
+#ifdef WINNT_NATIVE
     cp = SAVE(getcwd(NULL, 0));
-#else /* !WINNT */
+#else /* !WINNT_NATIVE */
     cp = dcanon(cp, dp);
-#endif /* WINNT */
+#endif /* WINNT_NATIVE */
     return cp;
 }
 
@@ -814,6 +814,7 @@ dcanon(cp, p)
 #ifdef apollo
     bool    slashslash;
 #endif /* apollo */
+    size_t  clen;
 
 #ifdef S_IFLNK			/* if we have symlinks */
     Char    link[MAXPATHLEN];
@@ -823,23 +824,34 @@ dcanon(cp, p)
 #endif /* S_IFLNK */
 
     /*
-     * kim: if the path given is too long abort().
+     * if the path given is too long truncate it!
      */
-    if (Strlen(cp) >= MAXPATHLEN)
-	abort();
+    if ((clen = Strlen(cp)) >= MAXPATHLEN)
+	cp[clen = MAXPATHLEN - 1] = '\0';
 
     /*
      * christos: if the path given does not start with a slash prepend cwd. If
-     * cwd does not start with a slash or the result would be too long abort().
+     * cwd does not start with a slash or the result would be too long try to
+     * correct it.
      */
     if (!ABSOLUTEP(cp)) {
 	Char    tmpdir[MAXPATHLEN];
+	size_t	len;
 
 	p1 = varval(STRcwd);
-	if (p1 == STRNULL || !ABSOLUTEP(p1))
-	    abort();
-	if (Strlen(p1) + Strlen(cp) + 1 >= MAXPATHLEN)
-	    abort();
+	if (p1 == STRNULL || !ABSOLUTEP(p1)) {
+	    char *tmp = (char *)getcwd((char *)tmpdir, sizeof(tmpdir));
+	    if (tmp == NULL || *tmp == '\0') {
+		xprintf("%s: %s\n", progname, strerror(errno));
+		set(STRcwd, SAVE("/"), VAR_READWRITE|VAR_NOGLOB);
+	    } else {
+		set(STRcwd, SAVE(tmp), VAR_READWRITE|VAR_NOGLOB);
+	    }
+	    p1 = varval(STRcwd);
+	}
+	len = Strlen(p1);
+	if (len + clen + 1 >= MAXPATHLEN)
+	    cp[MAXPATHLEN - (len + 1)] = '\0';
 	(void) Strcpy(tmpdir, p1);
 	(void) Strcat(tmpdir, STRslash);
 	(void) Strcat(tmpdir, cp);
@@ -847,11 +859,6 @@ dcanon(cp, p)
 	cp = p = Strsave(tmpdir);
     }
 
-#ifdef COMMENT
-    if (*cp != '/')
-	abort();
-#endif /* COMMENT */
-
 #ifdef apollo
     slashslash = (cp[0] == '/' && cp[1] == '/');
 #endif /* apollo */
@@ -1348,7 +1355,7 @@ recdirs(fname, def)
 	return;
     }
 
-    if ((snum = varval(STRsavedirs)) == STRNULL) 
+    if ((snum = varval(STRsavedirs)) == STRNULL || snum[0] == '\0') 
 	num = (unsigned int) ~0;
     else
 	num = (unsigned int) atoi(short2str(snum));
