@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/sh.set.c,v 3.37 2000/07/15 19:58:51 christos Exp $ */
+/* $Header: /src/pub/tcsh/sh.set.c,v 3.39 2001/03/18 19:06:30 christos Exp $ */
 /*
  * sh.set.c: Setting and Clearing of variables
  */
@@ -36,7 +36,7 @@
  */
 #include "sh.h"
 
-RCSID("$Id: sh.set.c,v 3.37 2000/07/15 19:58:51 christos Exp $")
+RCSID("$Id: sh.set.c,v 3.39 2001/03/18 19:06:30 christos Exp $")
 
 #include "ed.h"
 #include "tw.h"
@@ -160,6 +160,9 @@ update_vars(vp)
     else if (eq(vp, STRrecognize_only_executables)) {
 	tw_cmd_free();
     }
+    else if (eq(vp, STRkillring)) {
+	SetKillRing(getn(varval(vp)));
+    }
 #ifndef HAVENOUTMP
     else if (eq(vp, STRwatch)) {
 	resetwatch();
@@ -740,6 +743,8 @@ unset(v, c)
 	symlinks = 0;
     if (adrof(STRimplicitcd) == 0)
 	implicit_cd = 0;
+    if (adrof(STRkillring) == 0)
+	SetKillRing(0);
     if (did_edit && noediting && adrof(STRedit) == 0)
 	noediting = 0;
     if (did_roe && adrof(STRrecognize_only_executables) == 0)
@@ -1103,6 +1108,8 @@ update_dspmbyte_vars()
 	    iskcode = 1;
 	else if (eq(dstr1, STRKEUC))
 	    iskcode = 2;
+	else if (eq(dstr1, STRKBIG5))
+	    iskcode = 3;
 	else if ((dstr1[0] - '0') >= 0 && (dstr1[0] - '0') <= 3) {
 	    iskcode = 0;
 	}
@@ -1127,6 +1134,11 @@ update_dspmbyte_vars()
 		_cmap[lp] = _cmap_mbyte[lp];
 		_mbmap[lp] = _mbmap_euc[lp];
 		break;
+	    case 3:
+		/* 3 ... big5 */
+		_cmap[lp] = _cmap_mbyte[lp];
+		_mbmap[lp] = _mbmap_big5[lp];
+		break;
 	    default:
 		xprintf(CGETS(18, 3,
 		    "Warning: unknown multibyte code %d; multibyte disabled\n"),
@@ -1204,6 +1216,7 @@ autoset_dspmbyte(pcp)
 	{ STRLANGEUCKRB, STRKEUC },
 	{ STRLANGSJIS, STRKSJIS },
 	{ STRLANGSJISB, STRKSJIS },
+	{ STRLANGBIG5, STRKBIG5 },
 	{ NULL, NULL }
     };
 
