@@ -1,4 +1,4 @@
-/* $Header: /src/pub/tcsh/tc.decls.h,v 3.45 2000/07/15 19:58:51 christos Exp $ */
+/* $Header: /src/pub/tcsh/tc.decls.h,v 3.49 2001/08/06 23:57:33 christos Exp $ */
 /*
  * tc.decls.h: Function declarations from all the tcsh modules
  */
@@ -41,12 +41,12 @@
  * tc.alloc.c
  */
 #ifndef SYSMALLOC
-#ifndef WINNT
+#ifndef WINNT_NATIVE
 extern	void		  free		__P((ptr_t));
 extern	memalign_t	  malloc	__P((size_t));
 extern	memalign_t	  realloc	__P((ptr_t, size_t));
 extern	memalign_t	  calloc	__P((size_t, size_t));
-#endif /* !WINNT */
+#endif /* !WINNT_NATIVE */
 #else /* SYSMALLOC */
 extern	void		  sfree		__P((ptr_t));
 extern	memalign_t	  smalloc	__P((size_t));
@@ -96,6 +96,7 @@ extern	void		  postcmd	__P((void));
 extern	void		  cwd_cmd	__P((void));
 extern	void		  beep_cmd	__P((void));
 extern	void		  period_cmd	__P((void));
+extern	void		  job_cmd	__P((Char *));
 extern	void		  aliasrun	__P((int, Char *, Char *));
 extern	void		  setalarm	__P((int));
 extern	void		  rmstar	__P((struct wordent *));
@@ -272,7 +273,7 @@ extern	void 		  sigpause	__P((int));
 extern	sigret_t	(*xsignal	__P((int, sigret_t (*)(int)))) ();
 # define signal(a, b)	  xsignal(a, b)
 #endif /* NEEDsignal */
-#if defined(_SEQUENT_) || ((SYSVREL > 3 || defined(_DGUX_SOURCE)) && defined(POSIXSIGS)) || ((defined(_AIX) || defined(__CYGWIN__)) && defined(POSIXSIGS)) || defined(WINNT)
+#if defined(_SEQUENT_) || ((SYSVREL > 3 || defined(_DGUX_SOURCE)) && defined(POSIXSIGS)) || ((defined(_AIX) || defined(__CYGWIN__)) && defined(POSIXSIGS)) || defined(WINNT_NATIVE)
 extern	sigmask_t	  sigsetmask	__P((sigmask_t));
 # if !defined(DGUX) || (defined(DGUX) && defined(__ix86))
 extern	sigmask_t	  sigblock	__P((sigmask_t));
@@ -329,6 +330,7 @@ extern	const char 	 *who_info	__P((ptr_t, int, char *, size_t));
 extern	void		  dolog		__P((Char **, struct command *));
 # ifdef UTHOST
 extern	char		 *utmphost	__P((void));
+extern	size_t		  utmphostsize	__P((void));
 # endif /* UTHOST */
 #endif /* HAVENOUTMP */
 
